@@ -12,6 +12,8 @@ These include:
 
 from __future__ import division
 
+import warnings
+
 import numpy as np
 
 from ..constants import g, omega, Rd
@@ -40,6 +42,7 @@ def get_wind_speed(u, v):
     See Also
     --------
     get_wind_components
+
     """
     speed = np.sqrt(u * u + v * v)
     return speed
@@ -65,6 +68,7 @@ def get_wind_dir(u, v):
     See Also
     --------
     get_wind_components
+
     """
     wdir = 90. * units.deg - np.arctan2(-v, -u)
     origshape = wdir.shape
@@ -102,7 +106,9 @@ def get_wind_components(speed, wdir):
     >>> metpy.calc.get_wind_components(10. * units('m/s'), 225. * units.deg)
     (<Quantity(7.071067811865475, 'meter / second')>,
      <Quantity(7.071067811865477, 'meter / second')>)
+
     """
+    wdir = _check_radians(wdir, max_radians=4 * np.pi)
     u = -speed * np.sin(wdir)
     v = -speed * np.cos(wdir)
     return u, v
@@ -147,6 +153,7 @@ def windchill(temperature, speed, face_level_winds=False, mask_undefined=True):
     See Also
     --------
     heat_index
+
     """
     # Correct for lower height measurement of winds if necessary
     if face_level_winds:
@@ -200,6 +207,7 @@ def heat_index(temperature, rh, mask_undefined=True):
     See Also
     --------
     windchill
+
     """
     delta = temperature - 0. * units.degF
     rh2 = rh * rh
@@ -241,6 +249,7 @@ def pressure_to_height_std(pressure):
     Notes
     -----
     .. math:: Z = \frac{T_0}{\Gamma}[1-\frac{p}{p_0}^\frac{R\Gamma}{g}]
+
     """
     t0 = 288. * units.kelvin
     gamma = 6.5 * units('K/km')
@@ -248,6 +257,34 @@ def pressure_to_height_std(pressure):
     return (t0 / gamma) * (1 - (pressure / p0).to('dimensionless')**(Rd * gamma / g))
 
 
+@exporter.export
+@check_units('[length]')
+def height_to_pressure_std(height):
+    r"""Convert height data to pressures using the U.S. standard atmosphere.
+
+    The implementation inverts the formula outlined in [Hobbs1977]_ pg.60-61.
+
+    Parameters
+    ----------
+    height : `pint.Quantity`
+        Atmospheric height
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding pressure value(s)
+
+    Notes
+    -----
+    .. math:: p = p_0 e^{\frac{g}{R \Gamma} \text{ln}(1-\frac{Z \Gamma}{T_0})}
+
+    """
+    t0 = 288. * units.kelvin
+    gamma = 6.5 * units('K/km')
+    p0 = 1013.25 * units.mbar
+    return p0 * (1 - (gamma / t0) * height) ** (g / (Rd * gamma))
+
+
 @exporter.export
 def coriolis_parameter(latitude):
     r"""Calculate the coriolis parameter at each point.
@@ -263,5 +300,132 @@ def coriolis_parameter(latitude):
     -------
     `pint.Quantity`
         The corresponding coriolis force at each point
+
     """
+    latitude = _check_radians(latitude, max_radians=np.pi / 2)
     return 2. * omega * np.sin(latitude)
+
+
+@exporter.export
+@check_units('[pressure]', '[length]')
+def add_height_to_pressure(pressure, height):
+    r"""Calculate the pressure at a certain height above another pressure level.
+
+    This assumes a standard atmosphere.
+
+    Parameters
+    ----------
+    pressure : `pint.Quantity`
+        Pressure level
+    height : `pint.Quantity`
+        Height above a pressure level
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding pressure value for the height above the pressure level
+
+    See Also
+    -----
+    pressure_to_height_std, height_to_pressure_std, add_pressure_to_height
+
+    """
+    pressure_level_height = pressure_to_height_std(pressure)
+    return height_to_pressure_std(pressure_level_height + height)
+
+
+@exporter.export
+@check_units('[length]', '[pressure]')
+def add_pressure_to_height(height, pressure):
+    r"""Calculate the height at a certain pressure above another height.
+
+    This assumes a standard atmosphere.
+
+    Parameters
+    ----------
+    height : `pint.Quantity`
+        Height level
+    pressure : `pint.Quantity`
+        Pressure above height level
+
+    Returns
+    -------
+    `pint.Quantity`
+        The corresponding height value for the pressure above the height level
+
+    See Also
+    -----
+    pressure_to_height_std, height_to_pressure_std, add_height_to_pressure
+
+    """
+    pressure_at_height = height_to_pressure_std(height)
+    return pressure_to_height_std(pressure_at_height - pressure)
+
+
+@exporter.export
+@check_units('[dimensionless]', '[pressure]', '[pressure]')
+def sigma_to_pressure(sigma, psfc, ptop):
+    r"""Calculate pressure from sigma values.
+
+    Parameters
+    ----------
+    sigma : ndarray
+        The sigma levels to be converted to pressure levels.
+
+    psfc : `pint.Quantity`
+        The surface pressure value.
+
+    ptop : `pint.Quantity`
+        The pressure value at the top of the model domain.
+
+    Returns
+    -------
+    `pint.Quantity`
+        The pressure values at the given sigma levels.
+
+    Notes
+    -----
+    Sigma definition adapted from [Philips1957]_.
+
+    .. math:: p = \sigma * (p_{sfc} - p_{top}) + p_{top}
+
+    * :math:`p` is pressure at a given `\sigma` level
+    * :math:`\sigma` is non-dimensional, scaled pressure
+    * :math:`p_{sfc}` is pressure at the surface or model floor
+    * :math:`p_{top}` is pressure at the top of the model domain
+
+    """
+    if np.any(sigma < 0) or np.any(sigma > 1):
+        raise ValueError('Sigma values should be bounded by 0 and 1')
+
+    if psfc.magnitude < 0 or ptop.magnitude < 0:
+        raise ValueError('Pressure input should be non-negative')
+
+    return sigma * (psfc - ptop) + ptop
+
+
+def _check_radians(value, max_radians=2 * np.pi):
+    """Input validation of values that could be in degrees instead of radians.
+
+    Parameters
+    ----------
+    value : `pint.Quantity`
+        The input value to check.
+
+    max_radians : float
+        Maximum absolute value of radians before warning.
+
+    Returns
+    -------
+    `pint.Quantity`
+        The input value
+
+    """
+    try:
+        value = value.to('radians').m
+    except AttributeError:
+        pass
+    if np.greater(np.nanmax(np.abs(value)), max_radians):
+        warnings.warn('Input over {} radians. '
+                      'Ensure proper units are given.'.format(max_radians))
+    return value
