@@ -22,6 +22,7 @@ def area(poly):
     Returns
     -------
     area: float
+
     """
     a = 0.0
     n = len(poly)
@@ -45,12 +46,12 @@ def order_edges(edges):
     Returns
     -------
     ordered_edges: (2, N) ndarray
+
     """
     edge = edges[0]
     edges = edges[1:]
 
-    ordered_edges = list()
-    ordered_edges.append(edge)
+    ordered_edges = [edge]
 
     num_max = len(edges)
     while len(edges) > 0 and num_max > 0:
