@@ -5,7 +5,9 @@
 
 from __future__ import print_function
 
+import bz2
 from collections import namedtuple
+import gzip
 import logging
 from struct import Struct
 import zlib
@@ -25,11 +27,29 @@ except NameError:
     bytearray_to_buff = memoryview
 
 
+def open_as_needed(filename):
+    """Return a file-object given either a filename or an object.
+
+    Handles opening with the right class based on the file extension.
+
+    """
+    if hasattr(filename, 'read'):
+        return filename
+
+    if filename.endswith('.bz2'):
+        return bz2.BZ2File(filename, 'rb')
+    elif filename.endswith('.gz'):
+        return gzip.GzipFile(filename, 'rb')
+    else:
+        return open(filename, 'rb')
+
+
 class UnitLinker(object):
     r"""Wrap a :class:`metpy.io.cdm.Variable` and handle units.
 
     Converts any attached unit attribute to a class:`pint.Unit`. It also handles converting
     data returns to be instances of class:`pint.Quantity` rather than bare (unit-less) arrays.
+
     """
 
     def __init__(self, var):
@@ -39,6 +59,7 @@ class UnitLinker(object):
         ----------
         var : Variable
             The :class:`metpy.io.cdm.Variable` to be wrapped.
+
         """
         self._var = var
         try:
@@ -144,14 +165,11 @@ class Enum(object):
 
     def __init__(self, *args, **kwargs):
         """Initialize the mapping."""
-        self.val_map = dict()
         # Assign values for args in order starting at 0
-        for ind, a in enumerate(args):
-            self.val_map[ind] = a
+        self.val_map = {ind: a for ind, a in enumerate(args)}
 
         # Invert the kwargs dict so that we can map from value to name
-        for k in kwargs:
-            self.val_map[kwargs[k]] = k
+        self.val_map.update(zip(kwargs.values(), kwargs.keys()))
 
     def __call__(self, val):
         """Map an integer to the string representation."""
@@ -336,6 +354,7 @@ def zlib_decompress_all_frames(data):
     -------
         bytearray
             All decompressed bytes
+
     """
     frames = bytearray()
     data = bytes(data)
@@ -378,7 +397,7 @@ def hexdump(buf, num_bytes, offset=0, width=32):
         blocks = [hexfmt * blocksize for _ in range(actual_width // blocksize)]
 
         # Need to get any partial lines
-        num_left = actual_width % blocksize
+        num_left = actual_width % blocksize  # noqa: S001  Fix false alarm
         if num_left:
             blocks += [hexfmt * num_left + '--' * (blocksize - num_left)]
         blocks += ['--' * blocksize] * (width // blocksize - len(blocks))
