@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: BSD-3-Clause
 """Tools to process GINI-formatted products."""
 
+import contextlib
 from datetime import datetime
 try:
     from enum import Enum
@@ -14,9 +15,8 @@ import re
 
 import numpy as np
 
-from ._tools import Bits, IOBuffer, NamedStruct, zlib_decompress_all_frames
+from ._tools import Bits, IOBuffer, NamedStruct, open_as_needed, zlib_decompress_all_frames
 from .cdm import cf_to_proj, Dataset
-from ..cbook import is_string_like
 from ..package_tools import Exporter
 
 exporter = Exporter(globals())
@@ -79,6 +79,7 @@ class GiniFile(object):
     See Also
     --------
     GiniFile.to_dataset
+
     """
 
     missing = 255
@@ -148,16 +149,13 @@ class GiniFile(object):
             recognized with the extension ``'.gz'``, as are bzip2-ed files with
             the extension ``'.bz2'`` If `filename` is a file-like object,
             this will be read from directly.
+
         """
-        if is_string_like(filename):
-            fobj = open(filename, 'rb')
-            self.filename = filename
-        else:
-            fobj = filename
-            self.filename = 'No Filename'
+        fobj = open_as_needed(filename)
 
         # Just read in the entire set of data at once
-        self._buffer = IOBuffer.fromfile(fobj)
+        with contextlib.closing(fobj):
+            self._buffer = IOBuffer.fromfile(fobj)
 
         # Pop off the WMO header if we find it
         self.wmo_code = ''
@@ -241,6 +239,7 @@ class GiniFile(object):
         Returns
         -------
         Dataset
+
         """
         ds = Dataset()
 
