@@ -8,6 +8,9 @@ from . import _mpl  # noqa: F401
 
 from .skewt import *  # noqa: F403
 from .station_plot import *  # noqa: F403
+from ._util import add_metpy_logo, add_timestamp, add_unidata_logo
 
 __all__ = skewt.__all__[:]  # pylint: disable=undefined-variable
 __all__.extend(station_plot.__all__)  # pylint: disable=undefined-variable
+__all__.extend([add_metpy_logo, add_timestamp,
+                add_unidata_logo])  # pylint: disable=undefined-variable
