@@ -18,17 +18,18 @@ specific set of constraints (e.g. step size) for mapping.
        axes[0].set_title(cmap_category + ' colormaps', fontsize=14)
 
        for ax, name in zip(axes, cmap_list):
-           ax.imshow(gradient, aspect='auto', cmap=ctables.registry.get_colortable(name))
-           pos = list(ax.get_position().bounds)
-           x_text = pos[0] - 0.01
-           y_text = pos[1] + pos[3]/2.
-           fig.text(x_text, y_text, name, va='center', ha='right', fontsize=10)
+               ax.imshow(gradient, aspect='auto', cmap=ctables.registry.get_colortable(name))
+               pos = list(ax.get_position().bounds)
+               x_text = pos[0] - 0.01
+               y_text = pos[1] + pos[3]/2.
+               fig.text(x_text, y_text, name, va='center', ha='right', fontsize=10)
 
        # Turn off *all* ticks & spines, not just the ones with colormaps.
        for ax in axes:
            ax.set_axis_off()
 
    cmaps = list(ctables.registry.keys())
+   cmaps = [name for name in cmaps if name[-2:]!='_r']
    nrows = len(cmaps)
    gradient = np.linspace(0, 1, 256)
    gradient = np.vstack((gradient, gradient))
@@ -40,6 +41,7 @@ specific set of constraints (e.g. step size) for mapping.
 from __future__ import division
 
 import ast
+import contextlib
 import glob
 import logging
 import os.path
@@ -82,8 +84,9 @@ def read_colortable(fobj):
     List of tuples
         A list of the RGB color values, where each RGB color is a tuple of 3 floats in the
         range of [0, 1].
+
     """
-    ret = list()
+    ret = []
     try:
         for line in fobj:
             literal = _parse(line)
@@ -106,6 +109,7 @@ def convert_gempak_table(infile, outfile):
         The file-like object to read from
     outfile : file-like object
         The file-like object to write to
+
     """
     for line in infile:
         if not line.startswith('!') and line.strip():
@@ -129,11 +133,14 @@ class ColortableRegistry(dict):
             The package containing the resource directory
         path : str
             The path to the directory with the color tables
+
         """
         for fname in resource_listdir(pkg, path):
             if fname.endswith(TABLE_EXT):
-                self.add_colortable(resource_stream(pkg, posixpath.join(path, fname)),
-                                    posixpath.splitext(posixpath.basename(fname))[0])
+                table_path = posixpath.join(path, fname)
+                with contextlib.closing(resource_stream(pkg, table_path)) as stream:
+                    self.add_colortable(stream,
+                                        posixpath.splitext(posixpath.basename(fname))[0])
 
     def scan_dir(self, path):
         r"""Scan a directory on disk for color table files and add them to the registry.
@@ -142,6 +149,7 @@ class ColortableRegistry(dict):
         ----------
         path : str
             The path to the directory with the color tables
+
         """
         for fname in glob.glob(os.path.join(path, '*' + TABLE_EXT)):
             if os.path.isfile(fname):
@@ -162,8 +170,10 @@ class ColortableRegistry(dict):
             The file to read the color table from
         name : str
             The name under which the color table will be stored
+
         """
         self[name] = read_colortable(fobj)
+        self[name + '_r'] = self[name][::-1]
 
     def get_with_steps(self, name, start, step):
         r"""Get a color table from the registry with a corresponding norm.
@@ -185,6 +195,7 @@ class ColortableRegistry(dict):
         `matplotlib.colors.BoundaryNorm`, `matplotlib.colors.ListedColormap`
             The boundary norm based on `start` and `step` with the number of colors
             from the number of entries matching the color table, and the color table itself.
+
         """
         from numpy import arange
 
@@ -213,6 +224,7 @@ class ColortableRegistry(dict):
         `matplotlib.colors.BoundaryNorm`, `matplotlib.colors.ListedColormap`
             The boundary norm based on `start` and `end` with the number of colors
             from the number of entries matching the color table, and the color table itself.
+
         """
         from numpy import linspace
 
@@ -237,6 +249,7 @@ class ColortableRegistry(dict):
         -------
         `matplotlib.colors.BoundaryNorm`, `matplotlib.colors.ListedColormap`
             The boundary norm based on `boundaries`, and the color table itself.
+
         """
         cmap = self.get_colortable(name)
         return mcolors.BoundaryNorm(boundaries, cmap.N), cmap
@@ -253,6 +266,7 @@ class ColortableRegistry(dict):
         -------
         `matplotlib.colors.ListedColormap`
             The color table corresponding to `name`
+
         """
         return mcolors.ListedColormap(self[name], name=name)
 
