@@ -10,6 +10,7 @@ Contain tools for making Skew-T Log-P plots, including the base plotting class,
 from matplotlib.axes import Axes
 import matplotlib.axis as maxis
 from matplotlib.collections import LineCollection
+import matplotlib.colors as mcolors
 from matplotlib.patches import Circle
 from matplotlib.projections import register_projection
 import matplotlib.spines as mspines
@@ -19,7 +20,7 @@ import numpy as np
 
 from ._util import colored_line
 from ..calc import dewpoint, dry_lapse, moist_lapse, vapor_pressure
-from ..calc.tools import delete_masked_points
+from ..calc.tools import delete_masked_points, interp
 from ..package_tools import Exporter
 from ..units import units
 
@@ -164,6 +165,7 @@ class SkewXAxes(Axes):
 
         kwargs : Arbitrary keyword arguments
             Passed to :class:`matplotlib.axes.Axes`
+
         """
         # This needs to be popped and set before moving on
         self.rot = kwargs.pop('rotation', 30)
@@ -191,6 +193,7 @@ class SkewXAxes(Axes):
 
         This is called once when the plot is created to set up all the
         transforms for the data, text and grids.
+
         """
         # Get the standard transform setup from the Axes base class
         Axes._set_lim_and_transforms(self)
@@ -244,6 +247,7 @@ class SkewT(object):
     ax : `matplotlib.axes.Axes`
         The underlying Axes instance, which can be used for calling additional
         plot functions (e.g. `axvline`)
+
     """
 
     def __init__(self, fig=None, rotation=30, subplot=(1, 1, 1)):
@@ -264,6 +268,7 @@ class SkewT(object):
             :meth:`matplotlib.figure.Figure.add_subplot`. The
             :class:`matplotlib.gridspec.SubplotSpec`
             can be created by using :class:`matplotlib.gridspec.GridSpec`.
+
         """
         if fig is None:
             import matplotlib.pyplot as plt
@@ -305,6 +310,7 @@ class SkewT(object):
         See Also
         --------
         :func:`matplotlib.pyplot.semilogy`
+
         """
         # Skew-T logP plotting
         t, p = delete_masked_points(t, p)
@@ -319,11 +325,11 @@ class SkewT(object):
 
         # Try to make sane default temperature plotting
         self.ax.xaxis.set_major_locator(MultipleLocator(10))
-        self.ax.set_xlim(-50, 50)
 
         return l
 
-    def plot_barbs(self, p, u, v, xloc=1.0, x_clip_radius=0.08, y_clip_radius=0.08, **kwargs):
+    def plot_barbs(self, p, u, v, c=None, xloc=1.0, x_clip_radius=0.08,
+                   y_clip_radius=0.08, **kwargs):
         r"""Plot wind barbs.
 
         Adds wind barbs to the skew-T plot. This is a wrapper around the
@@ -338,6 +344,8 @@ class SkewT(object):
             U (East-West) component of wind
         v : array_like
             V (North-South) component of wind
+        c:
+            An optional array used to map colors to the barbs
         xloc : float, optional
             Position for the barbs, in normalized axes coordinates, where 0.0
             denotes far left and 1.0 denotes far right. Defaults to far right.
@@ -358,15 +366,21 @@ class SkewT(object):
         See Also
         --------
         :func:`matplotlib.pyplot.barbs`
+
         """
         # Assemble array of x-locations in axes space
         x = np.empty_like(p)
         x.fill(xloc)
 
         # Do barbs plot at this location
-        b = self.ax.barbs(x, p, u, v,
-                          transform=self.ax.get_yaxis_transform(which='tick2'),
-                          clip_on=True, **kwargs)
+        if c is not None:
+            b = self.ax.barbs(x, p, u, v, c,
+                              transform=self.ax.get_yaxis_transform(which='tick2'),
+                              clip_on=True, **kwargs)
+        else:
+            b = self.ax.barbs(x, p, u, v,
+                              transform=self.ax.get_yaxis_transform(which='tick2'),
+                              clip_on=True, **kwargs)
 
         # Override the default clip box, which is the axes rectangle, so we can have
         # barbs that extend outside.
@@ -405,6 +419,7 @@ class SkewT(object):
         :func:`~metpy.calc.thermo.dry_lapse`
         :meth:`plot_moist_adiabats`
         :class:`matplotlib.collections.LineCollection`
+
         """
         # Determine set of starting temps if necessary
         if t0 is None:
@@ -456,6 +471,7 @@ class SkewT(object):
         :func:`~metpy.calc.thermo.moist_lapse`
         :meth:`plot_dry_adiabats`
         :class:`matplotlib.collections.LineCollection`
+
         """
         # Determine set of starting temps if necessary
         if t0 is None:
@@ -504,6 +520,7 @@ class SkewT(object):
         See Also
         --------
         :class:`matplotlib.collections.LineCollection`
+
         """
         # Default mixing level values if necessary
         if w is None:
@@ -552,6 +569,7 @@ class SkewT(object):
         --------
         :class:`matplotlib.collections.PolyCollection`
         :func:`matplotlib.axes.Axes.fill_betweenx`
+
         """
         fill_properties = {'positive':
                            {'facecolor': 'tab:red', 'alpha': 0.4, 'where': x1 > x2},
@@ -601,6 +619,7 @@ class SkewT(object):
         --------
         :class:`matplotlib.collections.PolyCollection`
         :func:`matplotlib.axes.Axes.fill_betweenx`
+
         """
         return self.shade_area(p, t_parcel, t, which='positive', **kwargs)
 
@@ -629,6 +648,7 @@ class SkewT(object):
         --------
         :class:`matplotlib.collections.PolyCollection`
         :func:`matplotlib.axes.Axes.fill_betweenx`
+
         """
         return self.shade_area(p, t_parcel, t, which='negative', **kwargs)
 
@@ -647,6 +667,7 @@ class Hodograph(object):
     ----------
     ax : `matplotlib.axes.Axes`
         The underlying Axes instance used for all plotting
+
     """
 
     def __init__(self, ax=None, component_range=80):
@@ -659,6 +680,7 @@ class Hodograph(object):
         component_range : value
             The maximum range of the plot. Used to set plot bounds and control the maximum
             number of grid rings needed.
+
         """
         if ax is None:
             import matplotlib.pyplot as plt
@@ -689,10 +711,11 @@ class Hodograph(object):
         :class:`matplotlib.patches.Circle`
         :meth:`matplotlib.axes.Axes.axhline`
         :meth:`matplotlib.axes.Axes.axvline`
+
         """
         # Some default arguments. Take those, and update with any
         # arguments passed in
-        grid_args = dict(color='grey', linestyle='dashed')
+        grid_args = {'color': 'grey', 'linestyle': 'dashed'}
         if kwargs:
             grid_args.update(kwargs)
 
@@ -715,7 +738,7 @@ class Hodograph(object):
     @staticmethod
     def _form_line_args(kwargs):
         """Simplify taking the default line style and extending with kwargs."""
-        def_args = dict(linewidth=3)
+        def_args = {'linewidth': 3}
         def_args.update(kwargs)
         return def_args
 
@@ -741,15 +764,22 @@ class Hodograph(object):
         See Also
         --------
         :meth:`Hodograph.plot_colormapped`
+
         """
         line_args = self._form_line_args(kwargs)
         u, v = delete_masked_points(u, v)
         return self.ax.plot(u, v, **line_args)
 
-    def plot_colormapped(self, u, v, c, **kwargs):
+    def plot_colormapped(self, u, v, c, bounds=None, colors=None, **kwargs):
         r"""Plot u, v data, with line colored based on a third set of data.
 
-        Plots the wind data on the hodograph, but with a colormapped line.
+        Plots the wind data on the hodograph, but with a colormapped line. Takes a third
+        variable besides the winds and either a colormap to color it with or a series of
+        bounds and colors to create a colormap and norm to control colormapping.
+        The bounds must always be in increasing order. For using custom bounds with
+        height data, the function will automatically interpolate to the actual bounds from the
+        height and wind data, as well as convert the input bounds from
+        height AGL to height above MSL to work with the provided heights.
 
         Simple wrapper around plot so that pressure is the first (independent)
         input. This is essentially a wrapper around `semilogy`. It also
@@ -763,6 +793,10 @@ class Hodograph(object):
             v-component of wind
         c : array_like
             data to use for colormapping
+        bounds: array-like, optional
+            Array of bounds for c to use in coloring the hodograph.
+        colors: list, optional
+            Array of strings representing colors for the hodograph segments.
         kwargs
             Other keyword arguments to pass to :class:`matplotlib.collections.LineCollection`
 
@@ -774,9 +808,30 @@ class Hodograph(object):
         See Also
         --------
         :meth:`Hodograph.plot`
+
         """
-        line_args = self._form_line_args(kwargs)
         u, v, c = delete_masked_points(u, v, c)
+
+        if colors:
+            cmap = mcolors.ListedColormap(colors)
+            if bounds.dimensionality == {'[length]': 1.0}:
+                bounds = np.asarray(bounds + c[0]) * bounds.units
+                interp_vert = interp(bounds, c, c, u, v)
+                inds = np.searchsorted(c.magnitude, bounds.magnitude)
+                u = np.insert(u.magnitude, inds, interp_vert[1].magnitude)
+                v = np.insert(v.magnitude, inds, interp_vert[2].magnitude)
+                c = np.insert(c.magnitude, inds, interp_vert[0].magnitude)
+            else:
+                bounds = np.asarray(bounds) * bounds.units
+
+            norm = mcolors.BoundaryNorm(bounds.magnitude, cmap.N)
+            cmap.set_over('none')
+            cmap.set_under('none')
+            kwargs['cmap'] = cmap
+            kwargs['norm'] = norm
+            line_args = self._form_line_args(kwargs)
+        else:
+            line_args = self._form_line_args(kwargs)
         lc = colored_line(u, v, c, **line_args)
         self.ax.add_collection(lc)
         return lc
