@@ -26,10 +26,10 @@ class StationPlot(object):
     barbs as the center of the location.
     """
 
-    location_names = dict(C=(0, 0), N=(0, 1), NE=(1, 1), E=(1, 0), SE=(1, -1), S=(0, -1),
-                          SW=(-1, -1), W=(-1, 0), NW=(-1, 1))
+    location_names = {'C': (0, 0), 'N': (0, 1), 'NE': (1, 1), 'E': (1, 0), 'SE': (1, -1),
+                      'S': (0, -1), 'SW': (-1, -1), 'W': (-1, 0), 'NW': (-1, 1)}
 
-    def __init__(self, ax, x, y, fontsize=10, spacing=None, transform=None):
+    def __init__(self, ax, x, y, fontsize=10, spacing=None, transform=None, **kwargs):
         """Initialize the StationPlot with items that do not change.
 
         This sets up the axes and station locations. The `fontsize` and `spacing`
@@ -51,6 +51,11 @@ class StationPlot(object):
             station plot elements.
         transform : matplotlib.transforms.Transform (or compatible)
             The default transform to apply to the x and y positions when plotting.
+        kwargs
+            Additional keyword arguments to use for matplotlib's plotting functions.
+            These will be passed to all the plotting methods, and thus need to be valid
+            for all plot types, such as `clip_on`.
+
         """
         self.ax = ax
         self.x = x
@@ -58,8 +63,9 @@ class StationPlot(object):
         self.fontsize = fontsize
         self.spacing = fontsize if spacing is None else spacing
         self.transform = transform
-        self.items = dict()
+        self.items = {}
         self.barbs = None
+        self.default_kwargs = kwargs
 
     def plot_symbol(self, location, codes, symbol_mapper, **kwargs):
         """At the specified location in the station model plot a set of symbols.
@@ -149,6 +155,7 @@ class StationPlot(object):
         See Also
         --------
         plot_barb, plot_parameter, plot_text
+
         """
         # Make sure we use our font for symbols
         kwargs['fontproperties'] = wx_symbol_font.copy()
@@ -185,6 +192,7 @@ class StationPlot(object):
         See Also
         --------
         plot_barb, plot_symbol, plot_text
+
         """
         text = self._to_string_list(parameter, formatter)
         return self.plot_text(location, text, **kwargs)
@@ -215,13 +223,11 @@ class StationPlot(object):
         See Also
         --------
         plot_barb, plot_parameter, plot_symbol
+
         """
         location = self._handle_location(location)
 
-        # Pass transform if necessary
-        if 'transform' not in kwargs and self.transform:
-            kwargs['transform'] = self.transform
-
+        kwargs = self._make_kwargs(kwargs)
         text_collection = self.ax.scattertext(self.x, self.y, text, loc=location,
                                               size=kwargs.pop('fontsize', self.fontsize),
                                               **kwargs)
@@ -250,11 +256,14 @@ class StationPlot(object):
         See Also
         --------
         plot_parameter, plot_symbol, plot_text
+
         """
+        kwargs = self._make_kwargs(kwargs)
+
         # Handle transforming our center points. CartoPy doesn't like 1D barbs
         # TODO: This can be removed for cartopy > 0.14.3
-        if hasattr(self.ax, 'projection') and (self.transform or 'transform' in kwargs):
-            trans = kwargs.pop('transform', None) or self.transform
+        if hasattr(self.ax, 'projection') and 'transform' in kwargs:
+            trans = kwargs.pop('transform')
             x, y, _ = self. ax.projection.transform_points(trans, self.x, self.y).T
         else:
             x, y = self.x, self.y
@@ -262,8 +271,8 @@ class StationPlot(object):
         # Empirically determined
         pivot = 0.51 * np.sqrt(self.fontsize)
         length = 1.95 * np.sqrt(self.fontsize)
-        defaults = dict(sizes=dict(spacing=.15, height=0.5, emptybarb=0.35),
-                        length=length, pivot=pivot)
+        defaults = {'sizes': {'spacing': .15, 'height': 0.5, 'emptybarb': 0.35},
+                    'length': length, 'pivot': pivot}
         defaults.update(kwargs)
 
         # Remove old barbs
@@ -272,6 +281,21 @@ class StationPlot(object):
 
         self.barbs = self.ax.barbs(x, y, u, v, **defaults)
 
+    def _make_kwargs(self, kwargs):
+        """Assemble kwargs as necessary.
+
+        Inserts our defaults as well as ensures transform is present when appropriate.
+        """
+        # Use default kwargs and update with additional ones
+        all_kw = self.default_kwargs.copy()
+        all_kw.update(kwargs)
+
+        # Pass transform if necessary
+        if 'transform' not in all_kw and self.transform:
+            all_kw['transform'] = self.transform
+
+        return all_kw
+
     @staticmethod
     def _to_string_list(vals, fmt):
         """Convert a sequence of values to a list of strings."""
@@ -305,6 +329,7 @@ class StationPlotLayout(dict):
     See Also
     --------
     StationPlot
+
     """
 
     class PlotTypes(Enum):
@@ -352,6 +377,7 @@ class StationPlotLayout(dict):
         See Also
         --------
         add_barb, add_symbol, add_text
+
         """
         self[location] = (self.PlotTypes.value, name, (fmt, units, kwargs))
 
@@ -384,6 +410,7 @@ class StationPlotLayout(dict):
         See Also
         --------
         add_barb, add_text, add_value
+
         """
         self[location] = (self.PlotTypes.symbol, name, (symbol_mapper, kwargs))
 
@@ -412,6 +439,7 @@ class StationPlotLayout(dict):
         See Also
         --------
         add_barb, add_symbol, add_value
+
         """
         self[location] = (self.PlotTypes.text, name, kwargs)
 
@@ -444,6 +472,7 @@ class StationPlotLayout(dict):
         See Also
         --------
         add_symbol, add_text, add_value
+
         """
         # Not sure if putting the v_name as a plot-specific option is appropriate,
         # but it seems simpler than making name code in plot handle tuples
@@ -456,6 +485,7 @@ class StationPlotLayout(dict):
         -------
         list[str]
             the list of names of variables used by the layout
+
         """
         ret = []
         for item in self.values():
@@ -480,6 +510,7 @@ class StationPlotLayout(dict):
         data_dict : dict[str, array-like]
             Data container that maps a name to an array of data. Data from this object
             will be used to fill out the station plot.
+
         """
         def coerce_data(dat, u):
             try:
